class EfficiencyPoint(object):
  '''A simple struct that holds information related to analysis efficiency.
  
  signalEfficiency: the signal efficiency corresponding to the given parameters and cuts
  BGEfficiency:     corresponding background efficiency (mistag rate)
  parameters:       dictionary of input parameters to the analysis, e.g. {'R': 1.0, 'Rfilt': 0.3}
  cuts:             cuts for this efficiency point, e.g. {'AntiKt10_mass': (60.0, 100.0), 'AntiKt10_pt': (100.0, 1000.0)}
  '''
  def __init__(self, sigEff=1.0):
    self.signalEfficiency = sigEff
    self.BGEfficiency = 1.0
    self.parameters = {}
    self.cuts = {}

  def __str__(self):
    return ' '.join([str(x) for x in [self.signalEfficiency, self.BGEfficiency, self.parameters, self.cuts]])

  def copy(self, effPoint):
    self.signalEfficiency = effPoint.signalEfficiency
    self.BGEfficiency = effPoint.BGEfficiency
    self.parameters = effPoint.parameters
    self.cuts = effPoint.cuts

