#!/usr/bin/env python

# Command line arguments are:
# analysis Npoints sigfile_pattern BGfile_pattern
# File patterns can either be simple file names or shell-style globbing
#  expressions, in which case they should be quoted to protect the '*'s.
#  nVars is the number of analysis variables to cut on (takes the first n).
#  -1 for all, -2 for "best", given by analysis.bestNOutputVariables()

from sys import argv, exit
if (len(argv) != 6):
  print 'Usage: ./RunAnalysis analysis Nvars Npoints sigfile_pattern BGfile_pattern'
  exit(1)

from EfficiencyScanPreCut import EfficienciesParamScan
from Analyses import *

# The set of signal efficiencies to optimize for
# Note that using TMVA, we can basically check as many signal efficiencies at
#  once as we want
# Rounded to 2 decimal places to avoid things like (0.35 in sigEffs) == False
#  because 35*0.01 = 0.35000000000000003
# (Yes, using floats to key a dictionary is stupid.  This will be fixed...
#  eventually.)
sigEffs = [round(0.01 * n, 2) for n in range(1,76)]


analysisNameShort = argv[1]
analysisName = analysisNameShort+'Analysis'
# quick and dirty conversion to code: analysis name should be a global var
#  after doing 'from Analyses import *'
analysis = globals()[analysisName]

Nvars = int(argv[2])
Npoints = int(argv[3])

from glob import glob
sigFiles = glob(argv[4])
BGFiles = glob(argv[5])

bestEfficiencies = EfficienciesParamScan(analysis, Nvars, Npoints, sigFiles, BGFiles, sigEffs)

# output
out = open(analysisNameShort+'.eff.dat', 'w')
out.write('# {0}\n'.format(analysisName))
out.writelines([str(eff)+'\n' for eff in bestEfficiencies])
out.close

