#!/usr/bin/env python

# Command line arguments are:
# analysis nVars sigfile BGfile
#  sigfile and BGfile should be ROOT file storing output from some analysis
#  nVars is the number of analysis variables to cut on (takes the first n)
#  -1 for all, -2 for "best", given by analysis.bestNOutputVariables()

from sys import argv, exit
if (len(argv) != 5):
  print 'Usage: ./RunAnalysisSimple.py analysis nVars sigfile BGfile'
  exit(1)


from Analyses import *
from EfficiencyScan import EfficienciesFromFiles


# The set of signal efficiencies to optimize for
# Note that using TMVA, we can basically check as many signal efficiencies at
#  once as we want
sigEffs = [0.01 * n for n in range(1,76)]


analysisNameShort = argv[1]
analysisName = analysisNameShort+'Analysis'
# quick and dirty conversion to code: analysis name should be a global var
#  after doing 'from Analyses import *'
analysis = globals()[analysisName]() # get class name and create instance

nVars = int(argv[2])

sigFile = argv[3]
BGFile = argv[4]

bestEfficiencies = EfficienciesFromFiles(analysis, nVars, sigFile, BGFile, sigEffs)

# output
out = open(analysisNameShort+'.eff.dat', 'w')
out.write('# {0}\n'.format(analysisName))
out.writelines([str(eff)+'\n' for eff in bestEfficiencies])
out.close
