#!/usr/bin/env python

# Command line arguments are:
# analysis nVars sigfile BGfile
#  sigfile and BGfile should be ROOT file storing output from some analysis
#  nVars is the number of analysis variables to cut on (takes the first n)
#  -1 for all, -2 for "best", given by analysis.bestNOutputVariables()

from sys import argv, exit
if (len(argv) != 5):
  print 'Usage: ./RunCutScan.py analysis nVars sigfile BGfile'
  exit(1)


from Analyses import *
from EfficiencyScan import EfficienciesFromFiles


# The set of signal efficiencies to optimize for
# Note that using TMVA, we can basically check as many signal efficiencies at
#  once as we want
# Rounded to 2 decimal places to avoid things like (0.35 in sigEffs) == False
#  because 35*0.01 = 0.35000000000000003
# (Yes, using floats to key a dictionary is stupid.  This will be fixed...
#  eventually.)
sigEffs = [round(0.01 * n, 2) for n in range(1,76)]


# get class name and create instance with default params
analysisName = argv[1]
analysis = allAnalyses[analysisName]()

nVars = int(argv[2])

sigFile = argv[3]
BGFile = argv[4]

bestEfficiencies = EfficienciesFromFiles(analysis, nVars, sigFile, BGFile, sigEffs)

# output
out = open(analysisName+'.eff.dat', 'w')
out.write('# {0}\n'.format(analysisName))
out.writelines([str(eff)+'\n' for eff in bestEfficiencies])
out.close
