#!/usr/bin/env python

# This script implements all of the top taggers for the Boost 2011
# proceedings.  For each analysis, input parameters are taken from a TMVA
# efficiency scan, at the 35% signal efficiency point.  This information is
# stored in OptimizationData.py.  When possible cuts are not made, since this
# can be done afterward if the variables are stored.


# NOTE: SPARTYJETDIR/python must be in your PYTHONPATH.  You can set this by
# doing 'source setup.sh' in SPARTYJETDIR.
from sys import argv, exit
# put ROOT in batch mode
if argv[-1] != '-b': argv.append('-b')
from spartyjet import *
from Analyses import *
from OptimizationData import *
#===============================================

# silence useless ROOT warnings
import ROOT
ROOT.gErrorIgnoreLevel = 2001

if (len(argv) != 5):
  print len(argv)
  print argv
  print 'Usage: ./TopTagOpt.py MCName "input_pattern" output_file'
  exit(1)

# name of the Monte Carlo to pull optimization data for
MCName = argv[1]

from glob import glob
infiles = glob(argv[2])
outfile = argv[3]

# --------------------- Setup/Input ----------------------------------

# Create a jet builder
builder = SJ.JetBuilder(SJ.WARNING)
# Configure inputi
input = SJ.MultiInput()
for f in infiles:
  print "Opening: ", f
  input_i = getInputMaker(f)
  from os.path import basename as bn
  input_i.set_name(bn(f).split('.')[0])
  input.addInputMaker(input_i)
builder.configure_input(input, False)

# PDG id cut -- remove muons (13) and neutrinos (12, 14, 16)
ids = stdVector(-12, 12, 14, -14, 16, -16, 13, -13)
builder.add_jetTool_input(SJ.JetInputPdgIdSelectorTool(ids))
# Input eta cut
builder.add_jetTool_input(SJ.JetEtaCentralSelectorTool(-5.0,5.0))

# ------------------------- Analyses ---------------------------------
analysisTypes = [ATLAS, CMS, HEP, JohnsHopkins,
                 NSubjettiness, Pruned, Trimmed, ThalerWang]

for a in analysisTypes:
  if a in OptimalParametersDict[MCName]:
    print 'Creating analysis '+str(a)+' with parameters '+str(OptimalParametersDict[MCName][a])
    # create an instance, passing the stored optimal parameters
    analysis = a(**OptimalParametersDict[MCName][a])
    builder.add_analysis(analysis, False)
  else:
    # pass with default arguments if no data (or no parameters)
    builder.add_analysis(a(), False)


# --------------- Setup output and RUN -------------------------------------

# Configure output
builder.configure_output("Jets", outfile)

# Run SpartyJet
builder.print_event_every(100)
builder.process_events()

# Save this script in the ROOT file (needs to go after process_events or it
#  gets over-written!)
writeCurrentFile(outfile)

